<!-- 设备地域分布 -->
<template>
    <div class="data-overview">
        <div class="header">
            <div class="header-title">设备地域分布</div>
        </div>

        <div ref="chartRef" style="width: 100%; min-height: 300px"></div>
    </div>
</template>
<script lang="ts" name="EquipmentRegionDistribution" setup>
import { useMenuStore } from '@/store/menu';
import * as echarts from 'echarts';

const chartRef = ref<Record<string, any>>({});
const menu = useMenuStore();
let myChart: any = null;

const handleOptions = (x = [], y = []) => {
    const chart: any = chartRef.value;
    if (chart) {
        myChart = echarts.init(chart);
        const options = {
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow',
                },
            },
            legend: {
                data: ['Forest', 'Steppe', 'Desert', 'Wetland'],
            },
            grid: {
                top: '10%',
                left: '3%',
                right: '4%',
                bottom: '8%',
                containLabel: true,
            },
            xAxis: [
                {
                    type: 'category',
                    axisTick: { show: false },
                    data: ['2012', '2013', '2014', '2015', '2016'],
                },
            ],
            yAxis: [
                {
                    type: 'value',
                },
            ],
            series: [
                {
                    name: 'Forest',
                    type: 'bar',
                    barGap: '30%',
                    emphasis: {
                        focus: 'series',
                    },
                    barWidth: 20,
                    data: [320, 332, 301, 334, 390],
                },
                {
                    name: 'Steppe',
                    type: 'bar',
                    barGap: '30%',
                    emphasis: {
                        focus: 'series',
                    },
                    barWidth: 20,
                    data: [220, 182, 191, 234, 290],
                },
            ],
        };
        nextTick(() => {
            myChart.setOption(options);
            window.addEventListener('resize', function () {
                myChart.resize();
            });
        });
    }
};

watch(
    () => menu.collapsed,
    (newX) => {
        setTimeout(() => {
            myChart.resize();
        }, 300);
    },
);

onMounted(() => {
    handleOptions();
});
</script>
<style scoped lang="less">
.data-overview {
    padding: 16px;
    .header {
        display: flex;
        align-items: center;
        justify-content: space-between;
        .header-title {
            border-left: 3px solid #3468ff;
            padding-left: 8px;
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #333333;
            line-height: 23px;
        }
    }
}
</style>
